@@ -8,6 +8,8 @@ input four character station name, lowercase
 2021 November 2
 modified to use UNR database. Downloads it if you don't have it.
 Hopefully
+2021 November 26
+prints out XYZ too cause why not!
 
 """
 import argparse
@@ -31,7 +33,9 @@ def main():
     if len(station) != 4:
         print('illegal station name-must be 4 characters')
         sys.exit()
-    a,b,c=g.queryUNR_modern(station)
+    alat,alon,ht=g.queryUNR_modern(station)
+    x,y,z=g.llh2xyz(alat,alon,ht)
+    print('XYZ', round(x,4),round(y,4),round(z,4) )
     #a,b,c=g.queryUNR(station)
 
 if __name__ == "__main__":
