@@ -38,7 +38,7 @@ def read_snr_multiday(obsfile,obsfile2,twoDays):
         allGood1 = 1
 #        g.print_file_stats(ele,sat,s1,s2,s5,s6,s7,s8,e1,e2)
     except:
-        print('Could not read the first SNR file:', obsfile)
+        print('>>>>> Could not read the first SNR file:', obsfile)
 #
 #
 #
