@@ -7,12 +7,14 @@ import datetime
 import os
 import pickle
 import sys
+import wget
 
 import numpy as np
 from scipy.interpolate import interp1d
 
 import gnssrefl.gps as g
 
+
 def read_4by5(station, dlat,dlon,hell):
     """
     author: kristine m. larson
@@ -252,9 +254,6 @@ def readWrite_gpt2_1w(xdir, station, site_lat, site_lon):
     """
     PROJECT_ROOT = os.path.dirname(os.path.abspath(__file__))
     BASE_DIR = os.path.dirname(PROJECT_ROOT)
-    #print(PROJECT_ROOT)
-    # this appears to be the one i want
-    #print(BASE_DIR)
     try3 = PROJECT_ROOT + '/' + 'gpt_1wA.pickle'
 
     # check that output path exists.  
@@ -276,34 +275,41 @@ def readWrite_gpt2_1w(xdir, station, site_lat, site_lon):
 #   read VMF gridfile in pickle format 
         pname = xdir + '/input/' + 'gpt_1wA.pickle'
         print('The large refraction file should be stored here:', pname)
-        try:
+        foundit = False
+        if os.path.isfile(pname):
             f = open(pname, 'rb')
             [All_pgrid, All_Tgrid, All_Qgrid, All_dTgrid, All_U, All_Hs, All_ahgrid, All_awgrid, All_lagrid, All_Tmgrid] = pickle.load(f)
             f.close()
-        except:
-            print('I did not find it, I will look in current working directory')
-            try:
-                pname =  'gpt_1wA.pickle'
+            foundit = True
+        if not foundit:
+            pname =  'gnssrefl/gpt_1wA.pickle'
+            print('2nd attempt: subdirectory gnssrefl of current working directory:', pname)
+            if os.path.isfile(pname):
                 f = open(pname, 'rb')
                 [All_pgrid, All_Tgrid, All_Qgrid, All_dTgrid, All_U, All_Hs, All_ahgrid, All_awgrid, All_lagrid, All_Tmgrid] = pickle.load(f)
                 f.close()
+                foundit = True
+        if not foundit:
+            pname = try3
+            print('3rd attempt try here: ',pname)
+            if os.path.isfile(pname):
+                f = open(pname, 'rb')
+                [All_pgrid, All_Tgrid, All_Qgrid, All_dTgrid, All_U, All_Hs, All_ahgrid, All_awgrid, All_lagrid, All_Tmgrid] = pickle.load(f)
+                f.close()
+                foundit = True
+        if not foundit:
+            print('fourth attempt - download from github')
+            try:
+                pfile = 'gpt_1wA.pickle'
+                url= 'https://github.com/kristinemlarson/gnssrefl/raw/master/gnssrefl/' + pfile
+                wget.download(url,pfile)
+                subprocess.call(['mv','-f',pfile, xdir + '/input/' ])
+                foundit = True
             except:
-                print('hmm, failed again. ... try yet again here: ')
-                #cwd = os.getcwd()
-                #pname =  cwd + '/data/gpt_1wA.pickle'
-                pname =   try3
-                print(pname)
-                try:
-                    f = open(pname, 'rb')
-                    [All_pgrid, All_Tgrid, All_Qgrid, All_dTgrid, All_U, All_Hs, All_ahgrid, All_awgrid, All_lagrid, All_Tmgrid] = pickle.load(f)
-                    f.close()
-                except:
-                    print('could not get this done')
-                    print('download the missing gpt_1wA.pickle file from github and put it in the $REFL_CODE/input directory ')
-                    sys.exit()
+                print('download gpt_1wA.pickle from github and store in REFL_CODE/input')
+                sys.exit()
 
 
-#    print(np.shape(All_pgrid))
 # really should e zero to four, but whatever
         indx = np.zeros(4,dtype=int)
         indx_lat = np.zeros(4,dtype=int)
