@@ -130,7 +130,7 @@ def write_subdaily(outfile,station,ntv,writecsv,extraline,**kwargs):
         else:
             if extra:
                 fout.write(" {0:4.0f} {1:3.0f} {2:7.3f} {3:3.0f} {4:6.3f} {5:6.2f} {6:6.2f} {7:6.2f} {8:6.2f} {9:4.0f} {10:3.0f} {11:2.0f} {12:8.5f} {13:6.2f} {14:7.2f} {15:12.6f} {16:1.0f} {17:2.0f} {18:2.0f} {19:2.0f} {20:2.0f} {21:2.0f} {22:6.3f} {23:6.3f} \n".format(year, doy, rh,ntv[i,3],UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], \
-                            ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day,hour,minute, int(second), RHdot_corr[i], newRH[i]))
+                            ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day,hour,minute, int(second), newRH[i], RHdot_corr[i]))
             else:
                 fout.write(" {0:4.0f} {1:3.0f} {2:7.3f} {3:3.0f} {4:6.3f} {5:6.2f} {6:6.2f} {7:6.2f} {8:6.2f} {9:4.0f} {10:3.0f} {11:2.0f} {12:8.5f} {13:6.2f} {14:7.2f} {15:12.6f} {16:1.0f} {17:2.0f} {18:2.0f} {19:2.0f} {20:2.0f} {21:2.0f} \n".format(year, doy, rh,ntv[i,3],UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], \
                             ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day,hour,minute, int(second)))
@@ -147,21 +147,24 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
     extension is where the results files stored in that subdirectory ('' for default) 
     sigma is how many standard deviations away from mean you allow.   (float)
 
-    files now written out here rather than from subdaily_cl.py
+    files now written out here rather than in subdaily_cl.py
 
     author: kristine larson
     2021april27 return datetime object
+    2021november
     added azimuth, amplitude,peak2noise constraints
     allow file to be input
+    consolidated plots
     """
     # fontsize
-    fs = 12
+    fs = 10
     xdir = os.environ['REFL_CODE']
     # output will go to REFL_CODE/Files
     txtdir = xdir + '/Files'
     print('Will remove daily outliers greater than ', sigma, ' sigma')
     if not os.path.exists(txtdir):
         os.makedirs(txtdir)
+    print('Plot to the screen has been set to ', plt2screen)
 
     print('>>>>>>>>>>>>>>>>>>>>>>>> readin RH data <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<')
     if txtfile == '':
@@ -194,45 +197,7 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
         # using external file of concatenated results
         tv = np.loadtxt(txtfile,comments='%')
 
-    nr,nc=tv.shape
-    tvoriginal = tv
-    print('Number of initial RH retrievals', nr)
-    nroriginal = nr
-    if (nr == 0):
-        print('Exiting')
-        sys.exit()
-
-    t=tv[:,0] + (tv[:,1] + tv[:,4]/24)/365.25
-    rh = tv[:,2]
-
-    # sort the data
-    ii = np.argsort(t)
-    t = t[ii] ; rh = rh[ii]
-    # store the sorted data 
-    tv = tv[ii,:]
-
-    # apply azimuth constraints 
-    ii = (tv[:,5]  >= azim1) & (tv[:,5] <= azim2)
-    tv = tv[ii,:]
-    print(nr-len(tv) , ' points removed for azimuth constraints ',azim1,azim2)
-
-    # now apply amplitude constraint
-    nr,nc = tv.shape
-    ii = (tv[:,6]  >= ampl) ; tv = tv[ii,:]
-    print(nr-len(tv) , ' points removed for amplitude constraint ')
-
-    # now apply peak2noise constraint
-    nr,nc = tv.shape
-    ii = (tv[:,13]  >= peak2noise) ; tv = tv[ii,:]
-    print(nr-len(tv) , ' points removed for peak2noise constraints ')
-
-
-    # silly - why read it if you are not going to use it
-    # and restrict by doy - mostly to make testing go faster
-    ii = (tv[:,1] >= d1) & (tv[:,1] <= d2)
-    tv = tv[ii,:]
-    firstdoy = int(min(tv[:,1]))
-    lastdoy =  int(max(tv[:,1]))
+    tv,t,rh,fdoy,ldoy= apply_new_constraints(tv,azim1,azim2,ampl,peak2noise,d1,d2)
 
     tvoriginal = tv
     nr,nc = tvoriginal.shape
@@ -250,7 +215,8 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
     residuals = np.empty(shape=[0,1])
     nval = []; tval = []; y = tv[0,0]; 
     stats = np.empty(shape=[0,3])
-    for d in range(firstdoy,(lastdoy+1)):
+    # only look at the doy range where i have data
+    for d in range(fdoy,(ldoy+1)):
         ii = (tv[:,1] == d)
         dtime, iyear,imon,iday,ihour,imin,isec = g.ymd_hhmmss(year,d,12,True)
         tval.append(dtime)
@@ -264,107 +230,36 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
             b = ( tv[ii,2] - rhavg*np.ones( len(tv[ii,2]) ))/ rhstd
             residuals = np.append(residuals, b)
     #
-
-
-    ii = (np.absolute(residuals) > sigma)
-    jj = (np.absolute(residuals) < sigma)
+    ii = (np.absolute(residuals) > sigma) # data you like
+    jj = (np.absolute(residuals) < sigma) # data you do not like ;-)
     if plt2screen:
         fig,ax=plt.subplots()
         ax.plot(tval,nval,'bo')
         plt.title(station + ': number of RH retrievals each day',fontsize=fs)
-        plt.xticks(rotation =45,fontsize=fs)
-        plt.yticks(fontsize=fs)
+        plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
         plt.grid()
         fig.autofmt_xdate()
 
         minAz = float(np.min(tv[:,5])) ; maxAz = float(np.max(tv[:,5]))
-        fig,ax=plt.subplots()
-        # put some azimuth information on it
-        colors = tv[:,5]
-        # ax.plot( otimes, tv[:,2], '.')
-        # https://matplotlib.org/stable/gallery/lines_bars_and_markers/scatter_with_legend.html
-        scatter = ax.scatter(otimes,tv[:,2],marker='o', s=15, c=colors)
-        legend1 = ax.legend(*scatter.legend_elements(), bbox_to_anchor = (1.01, 0.8),title="Azim")
-        ax.add_artist(legend1)
-        plt.ylabel('meters',fontsize=fs)
-        plt.title('GNSS station: ' + station.upper() + ' Reflector Heights (azimuth)', fontsize=fs)
-        plt.gca().invert_yaxis()
-        plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
-        plt.grid() ; fig.autofmt_xdate()
-
-        plotname = txtdir + '/' + station + '_subdaily_azim_RH.png'
-        plt.savefig(plotname,dpi=300)
-        print('png file saved as: ', plotname)
-
-        fig,ax=plt.subplots()
-        # put some amplitude information on it
-        colors = tv[:,6]
-        # ax.plot( otimes, tv[:,2], '.')
-        # https://matplotlib.org/stable/gallery/lines_bars_and_markers/scatter_with_legend.html
-        scatter = ax.scatter(otimes,tv[:,2],marker='o', s=15, c=colors)
-        legend1 = ax.legend(*scatter.legend_elements(), bbox_to_anchor = (1.01, 0.8),title="Ampl")
-        ax.add_artist(legend1)
-        plt.ylabel('meters',fontsize=fs)
-        plt.title('GNSS station: ' + station.upper() + ' Reflector Heights (amplitude)', fontsize=fs)
-        plt.gca().invert_yaxis()
-        plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
-        plt.grid() ; fig.autofmt_xdate()
-
-        plotname = txtdir + '/' + station + '_subdaily_ampl_RH.png'
-        plt.savefig(plotname,dpi=300)
-        print('png file saved as: ', plotname)
-
-        # poor man's outlier detector
-        fig,ax=plt.subplots()
-        colors = tv[:,5]
-        # put some amplitude information on it
-        # ax.plot( otimes, tv[:,2], '.')
-        # https://matplotlib.org/stable/gallery/lines_bars_and_markers/scatter_with_legend.html
-        otimesarray = np.asarray(otimes)
-        plt.plot(otimes,tv[:,2], '.',color='gray',label='arcs')
-        plt.plot(stats[:,0], stats[:,1], 'o',markersize=8,color='blue',label='daily avg')
-        slabel = str(sigma) + ' sigma'
-        plt.plot(stats[:,0], stats[:,1]-sigma*stats[:,2], '--',color='black',label=slabel)
-        plt.plot(stats[:,0], stats[:,1]+sigma*stats[:,2], '--',color='black')
-        plt.plot(otimesarray[ii],tv[ii,2], '.',color='red',label='outliers',markersize=12)
-        plt.legend(loc="upper left")
-        plt.ylabel('meters',fontsize=fs)
-        plt.title('GNSS station: ' + station.upper() + ' Reflector Heights', fontsize=fs)
-        plt.gca().invert_yaxis()
-        plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
-        plt.grid() ; fig.autofmt_xdate()
-
-        plotname = txtdir + '/' + station + '_outlier_hunting.png'
-        plt.savefig(plotname,dpi=300)
-        print('png file saved as: ', plotname)
-
-        fig,ax=plt.subplots()
-        plt.plot(otimesarray[jj],tv[jj,2], '.',color='green',label='arcs')
-        plt.gca().invert_yaxis()
-        plt.ylabel('meters',fontsize=fs)
-        plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
-        plt.title('GNSS station: ' + station.upper() + ' Edited Reflector Heights', fontsize=fs)
-        plt.grid() ; fig.autofmt_xdate()
-        plotname = txtdir + '/' + station + '_outliers_removed.png'
-        plt.savefig(plotname,dpi=300)
-        print('png file saved as: ', plotname)
 
+        two_stacked_plots(otimes,tv,station,txtdir)
+        stack_two_more(otimes,tv,ii,jj,stats, station, txtdir,sigma)
         plt.show()
 
     # this might work... and then again, it might not
     print_badpoints(tv[ii,:],residuals[ii])
 
     # now write things out
-    fname = xdir + '/Files/' + station + '_subdaily_rh.txt'
-    fname_new = xdir + '/Files/' + station + '_subdaily_rh_edits.txt'
+    fname = xdir + '/Files/' + station + '_all.txt'
+    fname_new = xdir + '/Files/' + station + '_subdaily_edits.txt'
     extraline = ''
 
     editedtv = tv[jj,:]
     nr,nc = editedtv.shape
 
-    #print('Observations after constraints ', nroriginal)
     write_subdaily(fname,station,tvoriginal,writecsv,extraline)
     print('Edited observations',nr)
+    extraline = 'outliers removed/restrictions'
     write_subdaily(fname_new,station,editedtv,writecsv,extraline)
     NV = len(tvoriginal)
     print('Percent of observations removed: ', round(100*(NV-nr)/NV,2))
@@ -421,15 +316,14 @@ def fract_to_obstimes(spl_x):
 
     return obstimes
 
-def in_out(x,y):
+def spline_in_out(x,y,knots_per_day):
     """
-    inputs are numpy arrays of time (in years) and reflector heights (m)
+    inputs are numpy arrays of time (in doy) and reflector heights (m)
     outputs are the spline fit
 
     note: i have to assume this does not work well with data outages
     """
-    knots_per_day = 12
-    Ndays = 365.25*(x.max()-x.min())
+    Ndays = round(x.max()-x.min())
     numKnots = int(knots_per_day*(Ndays))
     #print('xmin, xmax',x.min(), x.max(), 'knots', numKnots,Ndays )
     x1 = x.min()+0.1/365.25
@@ -441,7 +335,7 @@ def in_out(x,y):
     xx = np.linspace(x.min(), x.max(), N)
     spline = interpolate.BSpline(t, c, k, extrapolate=False)
 
-    return x,spline(x) 
+    return xx,spline(xx) 
     
 def write_out_header(fout,station,extraline,**kwargs):
     """
@@ -459,7 +353,7 @@ def write_out_header(fout,station,extraline,**kwargs):
     fout.write('% Phase Center corrections have NOT been applied \n')
     if extra_columns:
         fout.write("% (1)  (2)   (3) (4)  (5)     (6)   (7)    (8)    (9)   (10)  (11) (12) (13)    (14)     (15)    (16) (17) (18,19,20,21,22) (23)    (24)\n")
-        fout.write("% year, doy, RH, sat,UTCtime, Azim, Amp,  eminO, emaxO,NumbOf,freq,rise,EdotF, PkNoise  DelT     MJD  refr  MM DD HH MM SS  RHcor  newRH\n")
+        fout.write("% year, doy, RH, sat,UTCtime, Azim, Amp,  eminO, emaxO,NumbOf,freq,rise,EdotF, PkNoise  DelT     MJD  refr  MM DD HH MM SS  newRH  RHcorr\n")
     else:
         fout.write("% (1)  (2)   (3) (4)  (5)     (6)   (7)    (8)    (9)   (10)  (11) (12) (13)    (14)     (15)    (16) (17) (18,19,20,21,22)\n")
         fout.write("% year, doy, RH, sat,UTCtime, Azim, Amp,  eminO, emaxO,NumbOf,freq,rise,EdotF, PkNoise  DelT     MJD  refr  MM DD HH MM SS \n")
@@ -538,13 +432,12 @@ def writejsonfile(ntv,station, outfile):
 
     return True
 
-def splines_for_dummies2(station,fname,fname_new,perday,pltit,outlierV,**kwargs):
+def rhdot_correction(station,fname,fname_new,pltit,outlierV,**kwargs):
     """
     inputs:
     station - 4 char
     fname - input filename 
     fname_new - output filename
-    perday is number of velocity measurements per day (interpolated)
     pltit - boolean for plots to the screen
     outlierV is meter outlier cutoff
 
@@ -553,15 +446,24 @@ def splines_for_dummies2(station,fname,fname_new,perday,pltit,outlierV,**kwargs)
 
     2021april27 sending obstimes as kwarg input
     2021may5 change file format back to original file format
-    author: kristine larson
-
-    where did splines_for_dummies go? LOL
-
     21may18 try to remove massive outliers
     21oct27 add usespline option because this code is not robust
+    can also input knots per day 
+
+    author: kristine larson
 
     """
-    fs = 12 # fontsize
+    # output will go to REFL_CODE/Files
+    xdir = os.environ['REFL_CODE']
+    txtdir = xdir + '/Files'
+
+#   how often do you want velocity computed (per day)
+    perday = 24*20 # so every 3 minutes
+    fs = 10 # fontsize
+    # making a knot every three hours ...
+    # knots_per_day = 8
+    knots_default = 8
+    knots_per_day= kwargs.get('knots',8)
     print('>>>>>>>>>>>>>>>>>>>> Entering spline fit <<<<<<<<<<<<<<<<<<<<<<<<')
     print('Input filename:', fname)
     print('Output filename: ', fname_new)
@@ -571,41 +473,24 @@ def splines_for_dummies2(station,fname,fname_new,perday,pltit,outlierV,**kwargs)
     if len(tvd) == 0:
         print('empty input file')
         return
-    # sort the data by days 
+    # sort the data in time
     ii = np.argsort( (tvd[:,1]+tvd[:,4]/24) ).T
     tvd = tvd[ii,:]
 
     NV = len(tvd)
-    # remove a median value
+    # remove a median value from RH
     medval = np.median(tvd[:,2])
     xx= tvd[:,2]-medval
-    plt_histograms = False
-    # turned off these plots at request of jupyter notebook users 
-    if plt_histograms:
-        plt.figure()
-        n, bins, patches = plt.hist(xx, 50, density=True, facecolor='g', alpha=0.75)
-        plt.xlabel('standard deviations')
-        plt.title('RH (median removed) ')
 
-    # use 3 sigma for the histogram plot
+    # use 3 sigma for the histogram plot ????
     Sig = np.std(xx)
     ij =  np.absolute(xx) < 3*Sig
     xnew = xx[ij]
 
-    if plt_histograms:
-        plt.figure()
-        plt.subplot(212)
-        n, bins, patches = plt.hist(xnew, 50, density=True, facecolor='g', alpha=0.75)
-        plt.xlabel('standard deviations')
-        plt.title('RH (median removed) without massive outliers')
-        if pltit:
-            plt.show()
-
     # sure looks like 3 sigma is being removed here! But this would get rid of a real storm surge
-    # perhaps not needed since 3 sigma could be taken out from the daily values
+    # perhaps not needed since 3 sigma should have been taken out from the daily values
     tvd = tvd[ij,:]
 
-
     # time variable in days
     th= tvd[:,1] + tvd[:,4]/24; 
     # reflector height (meters)
@@ -621,7 +506,8 @@ def splines_for_dummies2(station,fname,fname_new,perday,pltit,outlierV,**kwargs)
 
     # 
     fillgap = 1/24 # one hour fake values
-    gap = 4/24 # up to four hour gap allowed
+    # ???
+    gap = 5/24 # up to five hour gap allowed before warning
 
     tnew =[] ; ynew =[]; faket = []; 
     # fill in gaps using variables called tnew and ynew
@@ -634,12 +520,11 @@ def splines_for_dummies2(station,fname,fname_new,perday,pltit,outlierV,**kwargs)
             h0 = h[i-1:i+1]
             print('Gap on doy:', int(np.floor(x0[0])), ' lasting ', round(d*24,2), ' hours ')
             Ngaps = Ngaps + 1
-            #f = scipy.interpolate.interp1d(x0,h0)
-            f = scipy.interpolate.interp1d(x0,h0,'quadratic')
+            f = scipy.interpolate.interp1d(x0,h0)
+            #f = scipy.interpolate.interp1d(x0,h0,'quadratic')
             # so this is fake data
             ttnew = np.arange(th[i-1]+fillgap, th[i], fillgap)
             yynew = f(ttnew)
-            print(ttnew)
             faket = np.append(faket, ttnew)
             # now append it to your real data
             tnew = np.append(tnew,ttnew)
@@ -649,61 +534,37 @@ def splines_for_dummies2(station,fname,fname_new,perday,pltit,outlierV,**kwargs)
             ynew = np.append(ynew,h[i])
 
     if (Ngaps > 3):
-        print('This is a beta version of the spline fit code - and does not work well with gaps. Exiting for your own safety.')
-        sys.exit()
+        print('This is a beta version of the rhdot/spline fit code - and does not work well with gaps. You have been warned!')
     # sort it just to make sure ...
     ii = np.argsort( tnew) 
     tnew = tnew[ii]
     ynew = ynew[ii]
-#  should really just mirror it or remove data at the ends
-#   going to add more fake data ...
-    first = tnew[0]
-    last = tnew[-1]
-    ii = (tnew <= first + 0.1)
-    jj = (tnew >= last-0.1)
-    first6hours = np.mean(ynew[ii])
-    last6hours = np.mean(ynew[jj])
-    for ii in range(1,6):
-        tnew = np.append(tnew,first-ii/48)
-        ynew = np.append(ynew, first6hours)
-    for ii in range(1,6):
-        tnew = np.append(tnew,last+ii/48)
-        ynew = np.append(ynew, last6hours)
 
-    
-    # now sort them again .... 
-    ii = np.argsort(tnew) 
-    tnew = tnew[ii]
-    ynew = ynew[ii]
-
-    # making a knot every three hours ...
-    knots_per_day = 8
     Ndays = tnew.max()-tnew.min()
     numKnots = int(knots_per_day*(Ndays))
     print('First and last time values', '{0:8.3f} {1:8.3f} '.format (tnew.min(), tnew.max()) )
     print('Number of RH obs', len(h))
     print('Average obs per day', '{0:5.1f} '.format (len(h)/Ndays) )
-    print('Number of knots: ', numKnots)
+    print('Knots per day: ', knots_per_day, ' Number of knots: ', numKnots)
     print('Outlier criterion with respect to spline fit (m): ', outlierV)
     print('Number of days of data: ', '{0:8.2f}'.format ( Ndays) )
-    # need the first and last knot to be inside the time series
+    # need the first and last knot to be inside the time series ???
+    # 
+    # try this instead - first and last day
+    tt1 = tvd[0,1]
+    tt2 = tvd[-1,1] + 1
+    kdt = knots_per_day/24
+    knots = np.linspace(tt1 + kdt/2, tt2 - kdt/2, numKnots)
     firstKnot_in_minutes = 15
     t1 = tnew.min()+firstKnot_in_minutes/60/24
     t2 = tnew.max()-firstKnot_in_minutes/60/24
-    # try this 
-    # 
     knots =np.linspace(t1,t2,num=numKnots)
 
-    #ftest = open('testing.txt', 'w+')
-    #for i in range(0,len(knots)):
-    #    ftest.write('{0:9.4f} \n'.format( knots[i]))
-    #ftest.close()
 
     t, c, k = interpolate.splrep(tnew, ynew, s=0, k=3,t=knots,task=-1)
 
-    # user specifies how many values per day you want to send back to the user  
 
-    # should i do extrapolate True? it is the default  - could make it periodic?
+    # should i do extrapolate True? it is the default  
     #spline = interpolate.BSpline(t, c, k, extrapolate=True)
     spline = interpolate.BSpline(t, c, k, extrapolate=False)
     # equal spacing in both x and y
@@ -724,19 +585,21 @@ def splines_for_dummies2(station,fname,fname_new,perday,pltit,outlierV,**kwargs)
     if pltit:
         plt.figure()
         #plt.plot(obstimes, h, 'bo', label='Original points',markersize=3)
-        plt.plot(th, h, 'bo', label='Original points',markersize=3)
+        plt.plot(th, h, 'b.', label='Original points',markersize=3)
         # cannot use this because i do not have the year in the tnew variable
         #obstimes = fract_to_obstimes(spl_x)
         plt.plot(spl_x, spl_y, 'r', label='spline')
-        plt.title('Station: ' + station + ' Reflector Height')
+        plt.title( station.upper() + ' Reflector Heights')
         outlierstring = str(outlierV) + '(m) outliers'
-        plt.plot(th[j], h[j], 'co',label=outlierstring) 
+        plt.plot(th[j], h[j], 'c.',label=outlierstring) 
         plt.ylabel('meters',fontsize=fs)
         plt.xlabel('days',fontsize=fs)
         plt.grid()
         plt.gca().invert_yaxis()
         plt.legend(loc="upper left")
-
+        plotname = txtdir + '/' + station + '_rhdot1.png'
+        plt.savefig(plotname,dpi=300)
+        print('png file saved as: ', plotname)
 
 # take out these points
     th = th[i]; h = h[i]
@@ -744,23 +607,21 @@ def splines_for_dummies2(station,fname,fname_new,perday,pltit,outlierV,**kwargs)
     resid_spl = resid_spl[i]
     tvd = tvd[i,:]
 
-# should take out first and last six hours as well
+# taking out first and last six hours as well
     t1 = float(th[0] + 6/24)
     t2 = float(th[-1] - 6/24)
 # and again
-    i = (th >= t1)
+    i = (th >= t1) & (th <= t2)
     th = th[i]; h = h[i]
     xfac = xfac[i]
     resid_spl = resid_spl[i]
     tvd = tvd[i,:]
 
-    i = (th <= t2)
-    th = th[i]; h = h[i]
-    xfac = xfac[i]
-    resid_spl = resid_spl[i]
-    tvd = tvd[i,:]
-
-
+    #i = (th <= t2)
+    #th = th[i]; h = h[i]
+    #xfac = xfac[i]
+    #resid_spl = resid_spl[i]
+    #tvd = tvd[i,:]
 
 # put the original series without outliers eventually?
 # use first diff to get simple velocity.  
@@ -772,115 +633,335 @@ def splines_for_dummies2(station,fname,fname_new,perday,pltit,outlierV,**kwargs)
     yvel = obsPerHour*np.diff(spl_y)
 
     rhdot_at_th = np.interp(th, tvel, yvel)
-    #debug = open('debugging.txt', 'w+')
-    #for w in range(0,len(spl_x)):
-    #    debug.write(' {0:9.4f} {1:8.3f} \n'.format (spl_x[w], spl_y[w] ) )
-#
-#    debug.close()
     # this is the RHdot correction. This can be done better - 
     # this is just a start
     correction = xfac*rhdot_at_th
     #  this is where i should do a new spline fit with the corrected RH values
     # h = h - correction
 
-
     if pltit:
-        fig,ax=plt.subplots()
-        ax.plot(th, correction,'.',label='RHcorr')
+        fig=plt.figure(figsize=(12,6))
+        ax1=fig.add_subplot(311)
+        ijk = np.abs(correction) >  1
+        plt.plot(th, correction,'b.',label='RHcorr')
+        plt.plot(th[ijk], correction[ijk],'rx',label='suspect')
         plt.title('RHdot Correction',fontsize=fs)
-        plt.ylabel('meters',fontsize=fs); 
+        plt.ylabel('m',fontsize=fs);
         plt.grid()
-
-        fig,ax=plt.subplots()
-        ax.plot(tvel, yvel, '-',label='RHdot')
-        ax.plot(th, rhdot_at_th,'.',label='RHdot at obs')
-        plt.title('RHdot in meters per hour',fontsize=fs)
-        plt.ylabel('meters per hour',fontsize=fs); 
-        plt.xlabel('days of the year',fontsize=fs)
-        plt.grid()
-        plt.yticks(fontsize=fs)
-        plt.xticks(fontsize=fs)
-        ydiff = max(yvel) - min(yvel)
-        y2 = 0.1*ydiff + max(yvel)  ; y1 = min(yvel) - 0.1*ydiff
+        plt.setp(ax1.get_xticklabels(), visible=False)
         plt.xlim((th[0], th[-1]))
-        #print('min and max values', y1,y2,max(yvel), min(yvel))
 
-        #plt.ylim((y1,y2))
-        #fig.autofmt_xdate()
+        ax2=fig.add_subplot(312)
+        plt.plot(th, rhdot_at_th,'b.',label='at obs')
+        plt.plot(tvel[2:-2], yvel[2:-2], '-',color='orange',label='modeled')
+        plt.title('RHdot in meters per hour',fontsize=fs)
+        plt.ylabel('m/hr',fontsize=fs);
+        plt.legend(loc="best")
+        plt.grid()
+        plt.setp(ax2.get_xticklabels(), visible=False)
+        plt.yticks(fontsize=fs); plt.xticks(fontsize=fs)
+        plt.xlim((th[0], th[-1]))
 
-        #plt.figure()
-        fig,ax=plt.subplots()
+        ax3=fig.add_subplot(313)
         label1 = 'w/o RHdot ' + str( round(np.std(resid_spl),2)) + 'm'
         label2 = 'w/ RHdot ' + str(round(np.std(resid_spl-correction),2)) + 'm'
-        ax.plot(th, resid_spl,'.',label= label1)
-        ax.plot(th, resid_spl - correction,'.',label=label2)
-        plt.legend(loc="upper left")
+        plt.plot(th, resid_spl,'.',color='orange',label= label1)
+        plt.plot(th, resid_spl - correction,'b.',label=label2)
+        plt.plot(th[ijk], resid_spl[ijk] - correction[ijk],'rx',label='suspect')
+        plt.legend(loc="best")
         plt.xlabel('days of the year',fontsize=fs)
-        plt.ylabel('meters',fontsize=fs)
-        plt.yticks(fontsize=fs)
-        plt.xticks(fontsize=fs)
+        plt.ylabel('m',fontsize=fs)
+        plt.yticks(fontsize=fs); plt.xticks(fontsize=fs)
         plt.title('Reflector Height Residuals to the Spline Fit',fontsize=fs)
+        plt.xlim((th[0], th[-1]))
         plt.grid()
+
+        plotname = txtdir + '/' + station + '_rhdot2.png'
+        plt.savefig(plotname,dpi=300)
+        print('png file saved as: ', plotname)
         plt.show()
+
     print('RMS no RHdot correction (m)', '{0:6.3f}'.format ( np.std(resid_spl)) )
     print('RMS w/ RHdot correction (m)', '{0:6.3f}'.format ( np.std(resid_spl - correction))  )
     # this is RH with the RHdot correction
     correctedRH = resid_spl - correction
     print('Freq  Bias  Sigma   NumObs ')
     print('       (m)   (m)       ')
-    for f in [1, 20, 5, 101, 102, 201, 205,207,208]:
+    biasCorrected_RH = tvd[:,2] - correction
+    for f in [1, 2, 20, 5, 101, 102, 201, 205,207,208]:
         ff = (tvd[:,10] == f)
         ret = correctedRH[ff]
         if len(ret) > 0:
             print('{0:3.0f} {1:6.2f} {2:6.2f} {3:6.0f}'.format (f, np.mean(ret), np.std(ret), len(ret) ) )
+            biasCorrected_RH[ff] = biasCorrected_RH[ff] - np.mean(ret)
 
-    # put the correct RH in column 2
-    # but it would be good to keep the correction and the original value!
-    # and also chop off beginning and end
     writecsv = False; writetxt = True
-    extraline = 'Large outliers removed/two exta columns '
+    extraline = 'outliers removed/two new columns: corrected RH and the RHdot correction applied '
     newRH = tvd[:,2] - correction
     write_subdaily(fname_new,station,tvd,writecsv,extraline,newRH=newRH, RHdot_corr=correction)
     nr,nc = tvd.shape
     print('Percent of observations removed:', round(100*(NV-nr)/NV,2))
 
+    # doy
+    newt = tvd[:,1] + tvd[:,4]/24 ; 
+    redo_spline(newt, newRH, biasCorrected_RH,pltit,txtdir,station)
+
     return tvd, correction 
 
 
-def testing_hourly(tvd):
+
+def two_stacked_plots(otimes,tv,station,txtdir):
     """
-    this does not work
+    otimes - datetime
+    tv = gnssrefl results variable
+    station - name just for the title
+    txtdir is where the plots will be written to
+
+    author: kristine larson
     """
-    d1 = 15
-    d2 = 40
-    # start with hourly
-    t = tvd[:,1] + tvd[:,4]/24
-    rh = tvd[:,2]
-    rh_hourly = []; t_hourly = []
-    for d in range(d1,d2):
-        for h in range(0,24):
-            t1= d + h/24; t2= d + (h+1)/24;
-            ii = (t >= t1) & (t < t2)  
-            if len(rh[ii]) > 0:
-                avgRH = np.average(rh[ii])
-                #print(d,h,avgRH)
-                rh_hourly.append(avgRH)
-                # put each time at the half hour
-                t_hourly.append(d+(h+0.5)/24)
-            
-    plt.figure()
-    plt.plot(t_hourly, rh_hourly,'.')
-    plt.show()
+    fs = 10
+    fig,(ax1,ax2)=plt.subplots(2,1,sharex=True)
+        # put some azimuth information on it
+    colors = tv[:,5]
+        # ax.plot( otimes, tv[:,2], '.')
+        # https://matplotlib.org/stable/gallery/lines_bars_and_markers/scatter_with_legend.html
+    scatter = ax1.scatter(otimes,tv[:,2],marker='o', s=15, c=colors)
+    colorbar = fig.colorbar(scatter, ax=ax1)
+    colorbar.set_label('deg', fontsize=fs)
+    ax1.set_ylabel('meters',fontsize=fs)
+    fig.suptitle( station.upper() + ' Reflector Heights', fontsize=fs)
+    ax1.title.set_text('Azimuth')
+    plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
+    ax1.invert_yaxis()
+    ax1.grid(True)
+    fig.autofmt_xdate()
+
+# put some amplitude information on it
+    colors = tv[:,6]
+    # ax.plot( otimes, tv[:,2], '.')
+    # https://matplotlib.org/stable/gallery/lines_bars_and_markers/scatter_with_legend.html
+    scatter = ax2.scatter(otimes,tv[:,2],marker='o', s=15, c=colors)
+    colorbar = fig.colorbar(scatter, ax=ax2)
+    ax2.set_ylabel('meters',fontsize=fs)
+    plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
+    ax2.set_title('Amplitude')
+    ax2.invert_yaxis()
+    ax2.grid(True)
+    fig.autofmt_xdate()
+    colorbar.set_label('v/v', fontsize=fs)
+
+    plotname = txtdir + '/' + station + '_combined.png'
+    plt.savefig(plotname,dpi=300)
+    print('png file saved as: ', plotname)
+
+def stack_two_more(otimes,tv,ii,jj,stats, station, txtdir, sigma):
+    """
+    otimes - datetime object
+    tv - variable with the gnssrefl results
+    ii - good data?
+    jj - bad data?
+    station - for title
+    txtdir - where plots will be written
+    sigma is constraint used for the outlier detection
+ poor man's outlier detector
+    """
+    fs = 10
+    fig = plt.figure()
+    colors = tv[:,5]
+# put some amplitude information on it
+# ax.plot( otimes, tv[:,2], '.')
+# https://matplotlib.org/stable/gallery/lines_bars_and_markers/scatter_with_legend.html
+    otimesarray = np.asarray(otimes)
+
+    ax1 = fig.add_subplot(211)
+    plt.plot(otimes,tv[:,2], '.',color='gray',label='arcs')
+    plt.plot(stats[:,0], stats[:,1], '.',markersize=4,color='blue',label='daily avg')
+    slabel = str(sigma) + ' sigma'
+    plt.plot(stats[:,0], stats[:,1]-sigma*stats[:,2], '--',color='black',label=slabel)
+    plt.plot(stats[:,0], stats[:,1]+sigma*stats[:,2], '--',color='black')
+    plt.plot(otimesarray[ii],tv[ii,2], 'r.',markersize=4,label='outliers')
+    #plt.plot(otimesarray[ii],tv[ii,2], '.',color='red',label='outliers',markersize=12)
+    plt.legend(loc="best",bbox_to_anchor=(0.95, 0.9),prop={"size":8})
+    plt.ylabel('meters',fontsize=fs)
+    plt.title(station.upper() + ' Reflector Heights', fontsize=fs)
+    plt.gca().invert_yaxis()
+    plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
+    plt.grid() ; fig.autofmt_xdate()
+
+    ax2 = fig.add_subplot(212)
+    plt.plot(otimesarray[jj],tv[jj,2], '.',color='green',label='arcs')
+    plt.gca().invert_yaxis()
+    plt.ylabel('meters',fontsize=fs)
+    plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
+    plt.title('Edited Reflector Heights', fontsize=fs)
+    plt.grid() ; fig.autofmt_xdate()
+    plotname = txtdir + '/' + station + '_outliers_hunting.png'
+    plt.savefig(plotname,dpi=300)
+    print('png file saved as: ', plotname)
 
 
-#        plt.figure()
-#        #plt.plot(obstimes, h, 'bo', label='Original points',markersize=3)
-#        plt.plot(th, h, 'bo', label='Original points',markersize=3)
-#        plt.title('Station: ' + station + ' Reflector Height')
-#        plt.ylabel('meters',fontsize=fs)
-#        plt.xlabel('days',fontsize=fs)
-#        plt.grid()
-#        plt.gca().invert_yaxis()
-#        plt.legend(loc="upper left")
-#        plt.show()
+def apply_new_constraints(tv,azim1,azim2,ampl,peak2noise,d1,d2):
+    """
+    cleaning up the main code. this sorts data and applies various "commandline" constraints
+    tv is the full set of results from gnssrefl
+    t and rh are just time (in fractional doy) and reflector height
+    other inputs:
+    azim1-aimz2 - azimuth constraints in degrees
+    ampl is amplitude of the periodogram (volts/volts)
+    d1 and d2 are days of year
+    peak2noise 
+    """
+    nr,nc=tv.shape
+    tvoriginal = tv
+    print('Number of initial RH retrievals', nr)
+    nroriginal = nr
+    if (nr == 0):
+        print('Exiting')
+        sys.exit()
 
+    # not sure these need to be here - are they used elsewhere?
+    # could be moved to apply_new_constraints
+    t=tv[:,0] + (tv[:,1] + tv[:,4]/24)/365.25
+    rh = tv[:,2]
+
+# sort the data
+    ii = np.argsort(t)
+    t = t[ii] ; rh = rh[ii]
+    # store the sorted data
+    tv = tv[ii,:]
+
+    # apply azimuth constraints
+    ii = (tv[:,5]  >= azim1) & (tv[:,5] <= azim2)
+    tv = tv[ii,:]
+    print(nr-len(tv) , ' points removed for azimuth constraints ',azim1,azim2)
+
+    # now apply amplitude constraint
+    nr,nc = tv.shape
+    ii = (tv[:,6]  >= ampl) ; tv = tv[ii,:]
+    print(nr-len(tv) , ' points removed for amplitude constraint ')
+
+    # now apply peak2noise constraint
+    nr,nc = tv.shape
+    ii = (tv[:,13]  >= peak2noise) ; tv = tv[ii,:]
+    print(nr-len(tv) , ' points removed for peak2noise constraints ')
+
+
+    # silly - why read it if you are not going to use it
+    # and restrict by doy - mostly to make testing go faster
+    ii = (tv[:,1] >= d1) & (tv[:,1] <= d2)
+    tv = tv[ii,:]
+    firstdoy = int(min(tv[:,1]))
+    lastdoy =  int(max(tv[:,1]))
+
+    return tv,t,rh,firstdoy,lastdoy
+
+def redo_spline(tnew,ynew,biasCorr_ynew,pltit,txtdir,station):
+    """
+    having calculated and applied RHdot corretion
+    AND applied the frequency biases
+    tnew is in doy
+    ynew is rhdot corrected RH in meters (not currently used)
+    biasCorr_ynew has frequency biases removed (empirically defined)
+    pltit - boolean, for screen viewing
+    txtdir - where the plots will go ($REFL_CODE/Files
+    station - just for the title and name of plot
+
+    """
+    fs = 10
+    ynew = biasCorr_ynew
+    # now sort them again ....
+    ii = np.argsort(tnew)
+    tnew = tnew[ii]
+    ynew = ynew[ii]
+    outlierV = 0.5 # for now
+
+    # making a knot every three hours ...
+    knots_per_day = 8
+    Ndays = tnew.max()-tnew.min()
+    numKnots = int(knots_per_day*(Ndays))
+    NV = len(ynew)
+    print('First and last time values', '{0:8.3f} {1:8.3f} '.format (tnew.min(), tnew.max()) )
+    print('Number of RH obs', NV)
+    print('Number of days of data: ', '{0:8.2f}'.format ( Ndays) )
+    print('Average obs per day', '{0:5.1f} '.format (NV/Ndays) )
+    print('Number of knots: ', numKnots)
+    # need the first and last knot to be inside the time series
+    firstKnot_in_minutes = 15
+    t1 = tnew.min()+firstKnot_in_minutes/60/24
+    t2 = tnew.max()-firstKnot_in_minutes/60/24
+    # try this
+    #
+    knots =np.linspace(t1,t2,num=numKnots)
+    t, c, k = interpolate.splrep(tnew, ynew, s=0, k=3,t=knots,task=-1)
+
+    # user specifies how many values per day you want to send back to the user
+
+    # should i do extrapolate True? it is the default  - could make it periodic?
+    #spline = interpolate.BSpline(t, c, k, extrapolate=True)
+    spline = interpolate.BSpline(t, c, k, extrapolate=False)
+
+    # evenly spaced data - units of days
+    perday = 48 # so every 30 minutes in this case
+    N = int(Ndays*perday)
+    xx = np.linspace(tnew.min(), tnew.max(), N)
+    spl_x = xx; spl_y = spline(xx)
+    spline_at_tnew = spline(tnew)
+    plt.subplot(211)
+    plt.plot(tnew,ynew,'k.')
+    plt.plot(tnew,biasCorr_ynew,'b.',label='with freq/rhdot corr')
+    plt.plot(spl_x, spl_y,'-',color='orange',label='spline fit')
+    plt.title(station + ' RH Obs and new spline fit after freq bias removed')
+    plt.legend(loc="upper right")
+    plt.ylabel('meters')
+    plt.grid()
+
+    rms = np.std(ynew-spline_at_tnew)
+    newrms = str(round(rms,3))
+    print('std (m)', newrms)
+    ii = np.abs(ynew-spline_at_tnew) > 3*rms
+    jj = np.abs(ynew-spline_at_tnew) < 3*rms
+    res = ynew-spline_at_tnew
+    plt.subplot(212)
+    plt.plot(tnew,res,'b.', label='RH rms:' + newrms + ' m')
+    plt.plot(tnew[ii],res[ii],'r.',label='3sigma outliers')
+    #plt.title('residuals')
+    plt.xlabel('day of year'); plt.ylabel('meters')
+    plt.legend(loc="upper right")
+    plt.grid()
+    Ntot = len(res)
+    Nout = len(res[ii])
+    print('Percentage of 3-sigma outliers', round(100*Nout/Ntot,2))
+    #
+    plotname = txtdir + '/' + station + '_final.png'
+    plt.savefig(plotname,dpi=300)
+    print('png file saved as: ', plotname)
+    if pltit:
+        plt.show()
+
+
+
+#  should really just mirror it or remove data at the ends
+#   going to add more fake data ...
+#    first = tnew[0]
+#    last = tnew[-1]
+#    ii = (tnew <= first + 0.1)
+#    jj = (tnew >= last-0.1)
+#    first6hours = np.mean(ynew[ii])
+#    last6hours = np.mean(ynew[jj])
+#    for ii in range(1,6):
+#        tnew = np.append(tnew,first-ii/48)
+#        ynew = np.append(ynew, first6hours)
+#    for ii in range(1,6):
+#        tnew = np.append(tnew,last+ii/48)
+#        ynew = np.append(ynew, last6hours)
+
+
+    # now sort them again ....
+#   ii = np.argsort(tnew)
+#   tnew = tnew[ii]
+#   ynew = ynew[ii]
+
+    #ftest = open('testing.txt', 'w+')
+    #for i in range(0,len(knots)):
+    #    ftest.write('{0:9.4f} \n'.format( knots[i]))
+    #ftest.close()
