@@ -31,13 +31,14 @@ def main():
     parser.add_argument("station", help="station name", type=str)
     parser.add_argument("year", default=None, type=str, help="for now one year at a time")
     parser.add_argument("-txtfile", default=None, type=str, help="Filename for editing") 
-    parser.add_argument("-splinefile", default=None, type=str, help="Input filename for spline fitting (optional)") 
+    parser.add_argument("-splinefile", default=None, type=str, help="Input filename for rhdot/spline fitting (optional)") 
     parser.add_argument("-csvfile", default=None, type=str, help="set to True if you prefer csv to plain txt") 
     parser.add_argument("-plt", default=None, type=str, help="set to False to suppress plots")
-    parser.add_argument("-outlier", default=None, type=str, help="outlier criterion used in splinefit (meters)")
+    parser.add_argument("-spline_outlier", default=None, type=str, help="outlier criterion used in splinefit (meters)")
+    parser.add_argument("-knots", default=None, type=str, help="Knots per day, spline fit only (default is 8)")
     parser.add_argument("-sigma", default=None, type=str, help="simple sigma outlier criterion (e.g. 1 for 1sigma, 3 for 3sigma)")
     parser.add_argument("-extension", default=None, type=str, help="soln subdirectory")
-    parser.add_argument("-spline", default=None, type=str, help="set to True to turn on spline fitting for RHdot correction")
+    parser.add_argument("-rhdot", default=None, type=str, help="set to True to turn on spline fitting for RHdot correction")
     parser.add_argument("-doy1", default=None, type=str, help="initial day of year")
     parser.add_argument("-doy2", default=None, type=str, help="end day of year")
     parser.add_argument("-testing", default=None, type=str, help="set to True for testing mode")
@@ -72,11 +73,11 @@ def main():
         sigma = float(args.sigma)
 
     # if not specified, use outlier criterion of 0.5 m
-    # i believe this is only used for spline
-    if args.outlier == None:
-        outlier = 0.5 
+    # this is JUST for the splinefit. changed variable in thte input to make that more clear
+    if args.spline_outlier == None:
+        outlier = 1.0 
     else:
-        outlier = float(args.outlier)
+        outlier = float(args.spline_outlier)
 
 # these constraints are added at the command line
     azim1 = 0
@@ -96,7 +97,7 @@ def main():
         peak2noise = float(args.peak2noise)
 
     usespline = False # though it is dangerous
-    if args.spline == 'True':
+    if args.rhdot == 'True':
         usespline = True
 
 #   these are optional output options
@@ -131,27 +132,29 @@ def main():
             print('Input subdaily RH file you provided does not exist:', fname_new)
             sys.exit()
 
-    # I think these are used just for velocity ...
-    perday = 24*20 # yikes - every 3 minutes
-
     # testing added so that if it crashes, only effects me.  and I get more useful error messages
     # added spline input 2021 oct 27. It was not coded well enough for gaps etc.
-    input2spline = fname_new; output4spline = fname_new + '.rev'
+    # only allow plaint text?  i think that is what is really going on here
+    input2spline = fname_new; output4spline = fname_new + '.withrhdot'
+    if (args.knots== None):
+        knots = 8
+    else:
+        knots = int(args.knots)
     if usespline:
         if (args.testing == None): 
             try:
                 if haveObstimes:
-                    tv,corr = t.splines_for_dummies2(station,input2spline, output4spline, perday,plt,outlier,obstimes=obstimes)
+                    tv,corr = t.rhdot_correction(station,input2spline, output4spline, plt,outlier,obstimes=obstimes,knots=knots)
                 else:
-                    tv,corr = t.splines_for_dummies2(station,input2spline, output4spline, perday,plt,outlier)
+                    tv,corr = t.rhdot_correction(station,input2spline, output4spline, plt,outlier,knots=knots)
             except: 
+                print('Exited the spline code for unknown reasons. Run with testing as True if you want more info')
                 okok = 1
         else:
-            print('for me only')
             if haveObstimes:
-                tv,corr = t.splines_for_dummies2(station,input2spline, output4spline, perday,plt,outlier,obstimes=obstimes)
+                tv,corr = t.rhdot_correction(station,input2spline, output4spline, plt,outlier,obstimes=obstimes,knots=knots)
             else:
-                tv,corr = t.splines_for_dummies2(station,input2spline, output4spline, perday,plt,outlier)
+                tv,corr = t.rhdot_correction(station,input2spline, output4spline, plt,outlier,knots=knots)
 
 
 if __name__ == "__main__":
